@@ -10,6 +10,8 @@ function Graph() {
         this.padding_left = 75;
         this.smoothness = 0; // transition time in ms. Not ready yet
 
+        this.x_min = null;
+        this.x_max = null;
         this.y_min = null;
         this.y_max = null;
 
@@ -42,6 +44,8 @@ function Graph() {
             this.time_limit_input.attr("value", time_limit);
         }
     };
+    this.set_x_min = function(x_min) {};
+    this.set_x_max = function(x_max) {};
     this.set_y_min = function(y_min) {};
     this.set_y_max = function(y_max) {};
 
@@ -406,6 +410,7 @@ function TimePlot() {
         var y_min = parseFloat(this.y_min) || d3.min(self.data, function(d) { return parseFloat(d.value) });
         var y_max = parseFloat(this.y_max) || d3.max(self.data, function(d) { return parseFloat(d.value) });
         this.yScale.domain([y_min, y_max]);
+        this.yScale.clamp(true);
 
         this.svg.select(".x.axis")
             .transition()
@@ -468,6 +473,20 @@ function Histogram() {
                 self.set_nbins(parseInt(this.value));
             });
 
+
+        this.settings_menu.append('div').append('span').text('y-min:');
+        this.y_min_input = this.settings_menu.append('input')
+            .attr('value', this.y_min)
+            .on('input', function() {
+                self.set_y_min(this.value);
+            });
+        this.settings_menu.append('div').append('span').text('y-max:');
+        this.y_max_input = this.settings_menu.append('input')
+            .attr('value', this.y_max)
+            .on('input', function() {
+                self.set_y_max(this.value);
+            });
+
         this.settings_menu.append("div").append("span").text("y-axis scale:");
         this.y_scale_type_input = this.settings_menu.append("input")
             .attr("value", this.y_scale_type)
@@ -487,6 +506,22 @@ function Histogram() {
         }
     };
 
+    this.set_x_min = function(x_min) {
+        this.x_min = parseFloat(x_min);
+    };
+
+    this.set_x_max = function(x_max) {
+        this.x_max = parseFloat(x_max);
+    };
+
+    this.set_y_min = function(y_min) {
+        this.y_min = parseFloat(y_min);
+    };
+
+    this.set_y_max = function(y_max) {
+        this.y_max = parseFloat(y_max);
+    };
+
 
     this.setup_svg = function() {
         //this.reset_scales();
@@ -571,18 +606,35 @@ function Histogram() {
 
     this.draw_axes = function() {
         // Update scales and draw the axes
-        this.xScale.domain(d3.extent(this.map));
+
+        var x_min = parseFloat(this.x_min) || d3.min(this.map);
+        var x_max = parseFloat(this.x_max) || d3.max(this.map);
+        this.xScale.domain(d3.extent([x_min, x_max]));
         if (this.y_scale_type == 'lin') {
-            this.yScale.domain([0, d3.max(this.histogram, function(d) {
-                return d.length;
-            })]);
+            var y_min = parseFloat(this.y_min) || 0;
+            var y_max = parseFloat(this.y_max) || d3.max(this.histogram, function(d) { return d.length; });
+            if (y_min < 0) {
+                y_min = 1;
+            }
+            if (y_max < y_min) {
+                y_max = y_min + 1;
+            }
+            this.yScale.domain([y_min, y_max]);
         }
         if (this.y_scale_type == 'log') {
-            this.yScale.domain([1, d3.max(this.histogram, function(d) {
-                return d.length;
-            })]);
+            var y_min = parseFloat(this.y_min) || 1;
+            var y_max = parseFloat(this.y_max) || d3.max(this.histogram, function(d) { return d.length; });
+            if (y_min < 1) {
+                y_min = 1;
+            }
+            if (y_max < y_min) {
+                y_max = y_min + 1;
+            }
+            this.yScale.domain([y_min, y_max]);
         }
 
+        this.yScale.clamp(true);
+
         this.svg.select(".x.axis")
             .transition()
             .duration(this.smoothness)
@@ -608,7 +660,7 @@ function Histogram() {
     }
 
     this.histo_height = function(d) {
-        if (d.y < 1) {
+        if (d.y < 1 || self.xScale(d.x) < this.padding_left)  {
             return 0;
         } else {
             return (this.h - this.padding - self.yScale(d.y));
@@ -665,7 +717,9 @@ function Histogram() {
 
     this.redraw = function() {
         this.fetch_data();
-        this.map = self.data.map(function(i) { return parseFloat(i.value); });
+        this.map = self.data.map(function(i) {
+            return parseFloat(i.value);
+        });
         this.histogram = d3.layout.histogram().bins(this.nbins)(this.map);
         this.draw_axes();
         this.draw_bars();
@@ -812,6 +866,7 @@ function Equaliser() {
         var y_min = parseFloat(this.y_min) || d3.min(self.data, function(d) { return parseFloat(d.value) });
         var y_max = parseFloat(this.y_max) || d3.max(self.data, function(d) { return parseFloat(d.value) });
         this.yScale.domain([y_min, y_max]);
+        this.yScale.clamp(true);
 
         this.svg.select(".y.axis")
             .transition()
@@ -915,4 +970,4 @@ function Equaliser() {
     this.init();
 }
 
-Equaliser.prototype = new Graph();
\ No newline at end of file
+Equaliser.prototype = new Graph();
